# LightGBM runtime for MLServer

This package provides a MLServer runtime compatible with LightGBM.

## Usage

You can install the runtime, alongside `mlserver`, as:

```bash
pip install mlserver mlserver-lightgbm
```

For further information on how to use MLServer with LightGBM, you can check out
this [worked out example](../../docs/examples/lightgbm/README.md).
